****************
rail_project CLI
****************

.. click:: rail.cli.rail_project:project_cli
   :prog: rail-project
   :nested: none

==============================
Inspecting configuration files
==============================
	    
.. click:: rail.cli.rail_project:inspect_command
   :prog: rail-project inspect
   :nested: full

	    
=======================
Reducing input catalogs
=======================

.. click:: rail.cli.rail_project:reduce_command
   :prog: rail-project reduce
   :nested: full

      
==============================	    
Subsampling data from catalogs
==============================

.. click:: rail.cli.rail_project:subsample_command
   :prog: rail-project subsample
   :nested: full

	    	    
=====================================
Building pipeline configuration files
=====================================
	    	    
.. click:: rail.cli.rail_project:build_command
   :prog: rail-project build
   :nested: full

	    
=================
Running pipelines
=================

.. click:: rail.cli.rail_project:run_group
   :prog: rail-project run
   :nested: full



